@@ -10,21 +10,27 @@ import time
 ws = None
 h = None
 flag = True
+clientId = 0
 def getWsStatus():
     global ws
     global h
     global flag
+    global clientId
     while flag:
         if ws.closed:
             h.disconnect()
             flag = False
+            clientId += 1
+            h.addClientId()
         time.sleep(0.01)
 
 def handle(websocket, extensions, userPath):
     global ws
     global h
     global flag
+    global clientId
     ws = websocket
+    clientId = 0
     flag = True
     thread_flag = threading.Thread(target=getWsStatus)
     thread_flag.start()
@@ -35,7 +41,7 @@ def handle(websocket, extensions, userPath):
         if not message:
             continue
         try:
-            h.handle(message)
+            h.handle(message, clientId)
         except Exception as err:
             print("WS err %s" %err)
             h.sendReq('ws-error', {'code': KERR.WEBSOCKET_ERR, 'msg': str(err)})
